@@ -106,7 +106,7 @@ ddf.ds <-function(model, data, meta.data=list(), control=list(), call,
                                    standardize=TRUE, mono.points=20,
                                    mono.tol=1e-8, mono.delta=1e-7, debug=FALSE,
                                    nofit=FALSE, optimx.method="nlminb",
-                                   optimx.maxit=300)
+                                   optimx.maxit=300, silent=FALSE)
 
   #  Save current user options and then set design contrasts to treatment style
   save.options <- options()
@@ -182,7 +182,7 @@ ddf.ds <-function(model, data, meta.data=list(), control=list(), call,
                      mono.tol=control$mono.tol,
                      mono.delta=control$mono.delta,
                      debug=control$debug, nofit=control$nofit,
-                     left=meta.data$left
+                     left=meta.data$left, silent=control$silent
                     )
 
   # debug - print the initial values
