@@ -97,7 +97,7 @@ ddf.io.fi <- function(model,data,meta.data=list(),control=list(),
   options(contrasts=c("contr.treatment","contr.poly"))
 
   # Set up meta data values
-  meta.data=assign.default.values(meta.data, left=0, width=NA, binned=FALSE,
+  meta.data <- assign.default.values(meta.data, left=0, width=NA, binned=FALSE,
                                   int.range=NA, point=FALSE)
 
   # Set up control values
