@@ -4,7 +4,7 @@ solvecov <- function (m, cmax = 1e+10){
   options(show.error.messages = FALSE)
   covinv <- try(solve(m))
   if(class(covinv) != "try-error"){
-    coll = FALSE
+    coll <- FALSE
   }else{
     p <- nrow(m)
     cove <- eigen(m, symmetric = TRUE)
