@@ -2,7 +2,7 @@
 #'
 #' Computes one of a series of possible variance estimates for the observed encounter rate for a set of sample measurements (e.g., line lengths) and number of observations per sample.
 #'
-#' The choice of type follows the notation of Fewster et al. (2009) in that there are 8 choices of encounter rate variance that can be computed:
+#' The choice of type follows the notation of Fewster et al. (2009) in that there are 8 choices of encounter rate variance that can be computed for lines and one for points:
 #'
 #' \describe{
 #' \item{\code{R2}}{random line placement with unequal line lengths (design-assisted estimator)}
@@ -12,9 +12,11 @@
 #' \item{\code{S2}}{systematic line placement, post-stratification with no strata overlap, variances weighted by line length per stratum}
 #' \item{\code{O1}}{systematic line placement, post-stratification with overlapping strata (akin to S1)}
 #' \item{\code{O2}}{systematic line placement, post-stratification with overlapping strata (weighted by line length per stratum, akin to S2)}
-#' \item{\code{O3}}{systematic line placement, post-stratification with overlapping strata, model-assisted estimator with trend in encounter rate with line length}}
+#' \item{\code{O3}}{systematic line placement, post-stratification with overlapping strata, model-assisted estimator with trend in encounter rate with line length}
+#' \item{\code{P3}}{random point placement, potentially unequal number of visitsper point, model-based estimator}
+#' }
 #'
-#' Default value is \code{"R2"}, shown in Fewster et al. (2009) to have good performance for completely random designs. For systematic parallel line transect designs, Fewster et al. recommend \code{"O2"}.
+#' Default value is \code{"R2"}, shown in Fewster et al. (2009) to have good performance for completely random designs for lines. For systematic parallel line transect designs, Fewster et al. recommend \code{"O2"}. For point transects the default (and currently only implemented option) is \code{"P3"}.
 #'
 #' For the systematic estimators, pairs are assigned in the order they are given in the \code{lengths} and \code{groups} vectors.
 #'
@@ -29,7 +31,7 @@
 #' @param type choice of variance estimator to use for encounter rate
 #' @return Variance of encounter rate as defined by arguments
 #' @note This function is also used with different calling arguments to compute Innes et al variance of the estimated abundances/length rather than observation encounter rate. The function covn is probably only valid for R3 and R2.  Currently, the R2 form is used for all types other than R3.
-#' @author Jeff Laake
+#' @author Jeff Laake, David L Miller
 #' @references Fewster, R.M., S.T. Buckland, K.P. Burnham, D.L. Borchers, P.E.
 #'   Jupp, J.L. Laake and L. Thomas. 2009. Estimating the encounter rate
 #'   variance in distance sampling. Biometrics 65: 225-236.
@@ -42,11 +44,13 @@ varn <- function(lvec, nvec, type){
   k <- length(lvec)
 
   ## Go through the estimators one by one.
-  ## R2, R3, R4, S1, S2, O1, O2, O3
-  if(!(type %in% c("R2", "R3", "R4", "S1", "S2", "O1", "O2", "O3")))
+  if(!(type %in% c("R2", "R3", "R4", "S1", "S2", "O1", "O2", "O3", "P3")))
     stop (paste("Encounter rate variance type '", type,
                 "' is not recognized.", sep=""))
 
+  ## break if we use anything other than P3 with points or P3 with lines
+  ##   ^^^ tests for this are in dht() as we need to check the model object
+
   ## First the estimators based on the assumption of a random sample
   ## of lines: R2, R3, R4:
 
@@ -56,8 +60,8 @@ varn <- function(lvec, nvec, type){
     return(var.R2)
   }
 
-  ## Estimator R3: var.R3, sd.R3
-  if(type=="R3"){
+  ## Estimator R3 or P3
+  if(type=="R3" | type=="P3"){
     var.R3 <- 1/(L * (k - 1)) * sum(lvec * (nvec/lvec - ntot/L)^2)
     return(var.R3)
   }
